@@ -8,6 +8,8 @@
 #include <QFile>
 #include <QTextStream>
 #include <QMessageBox>
+#include <QRegExpValidator>
+#include <QRegExp>
 
 namespace Ui {
     class MainWindow;
@@ -32,8 +34,26 @@ private:
     QHash<QString, QString> variables;
     void readSettings();
     void writeSettings();
+    QString f1;
+    QString f2;
+    QString f3;
+    QString f4;
+    QString f5;
+    QString f6;
+    QString f7;
+    QString f8;
 
 private slots:
+    void on_font8_editingFinished();
+    void on_font7_editingFinished();
+    void on_fontbuttonpressed_clicked();
+    void on_fontbutton_clicked();
+    void on_font6_editingFinished();
+    void on_font5_editingFinished();
+    void on_font4_editingFinished();
+    void on_font3_editingFinished();
+    void on_font2_editingFinished();
+    void on_font1_editingFinished();
     void on_about_triggered();
     void on_fontimport_triggered();
     void on_fontdisabled_2_clicked();
